// -*- C++ -*-
/*!
 * @file  INPUT_CHECK.cpp
 * @brief Data input sample check
 * @date $Date$
 *
 * $Id$
 */

#include "INPUT_CHECK.h"

// Module specification
// <rtc-template block="module_spec">
static const char* input_check_spec[] =
  {
    "implementation_id", "INPUT_CHECK",
    "type_name",         "INPUT_CHECK",
    "description",       "Data input sample check",
    "version",           "0.1",
    "vendor",            "Vstone",
    "category",          "Test",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "0",
    "language",          "C++",
    "lang_type",         "compile",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
INPUT_CHECK::INPUT_CHECK(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_Mt1GainOut("Mt1Gain", m_Mt1Gain),
    m_Mt2GainOut("Mt2Gain", m_Mt2Gain),
    m_Mt1SpdOut("Mt1Spd", m_Mt1Spd),
    m_Mt2SpdOut("Mt2Spd", m_Mt2Spd),
    m_LED1Out("LED1", m_LED1),
    m_LED2Out("LED2", m_LED2),
    m_BuzPitchOut("BuzPitch", m_BuzPitch),
    m_BuzTimeOut("BuzTime", m_BuzTime),
    m_ModeOut("Mode", m_Mode)

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
INPUT_CHECK::~INPUT_CHECK()
{
}



RTC::ReturnCode_t INPUT_CHECK::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  
  // Set OutPort buffer
  addOutPort("Mt1Gain", m_Mt1GainOut);
  addOutPort("Mt2Gain", m_Mt2GainOut);
  addOutPort("Mt1Spd", m_Mt1SpdOut);
  addOutPort("Mt2Spd", m_Mt2SpdOut);
  addOutPort("LED1", m_LED1Out);
  addOutPort("LED2", m_LED2Out);
  addOutPort("BuzPitch", m_BuzPitchOut);
  addOutPort("BuzTime", m_BuzTimeOut);
  addOutPort("Mode", m_ModeOut);
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t INPUT_CHECK::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_CHECK::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_CHECK::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_CHECK::onActivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_CHECK::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

#define	GETPARAM(txt)	printf(txt); gets(str);

RTC::ReturnCode_t INPUT_CHECK::onExecute(RTC::UniqueId ec_id)
{
  char str[256];

  GETPARAM("\nget 'mode' ");
  m_Mode.data = atoi(str);
  m_ModeOut.write();

  GETPARAM("\nget 'mt1gain' ");
  m_Mt1Gain.data = atoi(str);
  m_Mt1GainOut.write();

  GETPARAM("\nget 'mt2gain' ");
  m_Mt2Gain.data = atoi(str);
  m_Mt2GainOut.write();

  GETPARAM("\nget 'mt1spd' ");
  m_Mt1Spd.data = atoi(str);
  m_Mt1SpdOut.write();

  GETPARAM("\nget 'mt2spd' ");
  m_Mt2Spd.data = atoi(str);
  m_Mt2SpdOut.write();

  GETPARAM("\nget 'LED1' ");
  m_LED1.data = atoi(str);
  m_LED1Out.write();

  GETPARAM("\nget 'LED2' ");
  m_LED2.data = atoi(str);
  m_LED2Out.write();

  GETPARAM("\nget 'BuzTime' ");
  m_BuzTime.data = atoi(str);
  m_BuzTimeOut.write();

  GETPARAM("\nget 'BuzPitch' ");
  m_BuzPitch.data = atoi(str);
  m_BuzPitchOut.write();

  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t INPUT_CHECK::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_CHECK::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_CHECK::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_CHECK::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_CHECK::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{
 
  void INPUT_CHECKInit(RTC::Manager* manager)
  {
    coil::Properties profile(input_check_spec);
    manager->registerFactory(profile,
                             RTC::Create<INPUT_CHECK>,
                             RTC::Delete<INPUT_CHECK>);
  }
  
};


